pyprocar.plotter.ProcarPlot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# pyprocar.plotter.ProcarPlot

class pyprocar.plotter.ProcarPlot(bands, spd, kpoints=None)

  A depeciated class ot plot the band structure

  Methods

  `ProcarPlot.__init__`(bands, spd[, kpoints]) |
  `ProcarPlot.atomicPlot`([cmap, vmin, vmax, ax]) | Just a handler to parametricPlot.
  `ProcarPlot.parametricPlot`([cmap, vmin, ...]) |
  `ProcarPlot.plotBands`([size, marker, ticks, ...]) |
  `ProcarPlot.scatterPlot`([size, mask, cmap, ...]) |